=============================
django-south-central
=============================

.. image:: https://badge.fury.io/py/south_central.png
    :target: https://badge.fury.io/py/south_central
    
.. image:: https://travis-ci.org/hiisi13/django-south-central.svg?branch=master   
    :target: https://travis-ci.org/hiisi13/django-south-central

.. image:: https://coveralls.io/repos/hiisi13/south_central/badge.png?branch=master
    :target: https://coveralls.io/r/hiisi13/south_central?branch=master

Run maintenance commands for Django apps in database migrations fashion 

Documentation
-------------

The full documentation is at https://south_central.readthedocs.org.

Quickstart
----------

Install django-south-central::

    pip install south_central

Then use it in a project::

    import south_central

Features
--------

* TODO
